import React, {useEffect, useRef, useState} from 'react';
import * as d3 from 'd3';
import '../style/chart.css'

const TimeGraph = () => {

    const [dataTest] = useState([
            {
                miliseconds: 100,
                seconds: 55,
                minutes: 0,
                date: "20.10.2022"
            },
            {
                miliseconds: 500,
                seconds: 15,
                minutes: 1,
                date: "21.10.2022"
            },
            {
                miliseconds: 20,
                seconds: 20,
                minutes: 1,
                date: "22.10.2022"
            },
            {
                miliseconds: 360,
                seconds: 8,
                minutes: 1,
                date: "23.10.2022"
            },
            {
                miliseconds: 400,
                seconds: 3,
                minutes: 1,
                date: "24.10.2022"
            },

            {
                miliseconds: 400,
                seconds: 3,
                minutes: 1,
                date: "24.10.2022"
            },
            {
                miliseconds: 400,
                seconds: 3,
                minutes: 1,
                date: "24.10.2022"
            },
            {
                miliseconds: 400,
                seconds: 3,
                minutes: 1,
                date: "24.10.2022"
            },
            {
                miliseconds: 400,
                seconds: 3,
                minutes: 1,
                date: "24.10.2022"
            },
    ]);

    const timeGraphRef = useRef();

    useEffect(() => {
        // setting up svg
        const w = 400;
        const h = 100;
        const svg = d3.select(timeGraphRef.current)
            .attr('width', w)
            .attr('height', h)
            .style('background', '#d3d3d3')
            .style('overflow', 'visible');
            
        // setting the scaling
        const xScale = d3.scaleLinear()
            .domain([0, dataTest.length - 1])
            .range([0, w]);

        const yScale = d3.scaleLinear()
            .domain([0, 90000])
            .range([h, 0]);
        
        const generateScaledLine = d3.line()
            .x((d, i) => xScale(i))
            .y(d => { return yScale(d.minutes * 60 * 1000 + d.seconds * 1000 + d.miliseconds); })
            .curve(d3.curveLinear);
            
        // setting the axes
        const xAxis = d3.axisBottom(xScale)
            .ticks(dataTest.length)
            .tickFormat(i => `${dataTest[i].date}`);
        
        const yAxis = d3.axisLeft(yScale)
            .ticks(5)
            .tickFormat(v => `${Math.floor(v/60000)}:${Math.floor((v - Math.floor(v/60000) * 60000)/1000)}`);

        svg.append('g')
            .call(xAxis)
            .attr('transform', `translate(0, ${h})`);
        
        svg.append('g')
            .call(yAxis);

        // setting up the data for the svg
        svg.selectAll('.line')
            .data([dataTest])
            .join('path')
            .attr('d', d => generateScaledLine(d))
            .attr('fill', 'none')
            .attr('stroke', 'black');
    
    }, [dataTest])

    return (
        <div className="graph">
            <svg ref={timeGraphRef} />
        </div>
    );
}

export default TimeGraph;

